%define up_name findlib
%bcond_without bootstrap

Summary:        A module packaging tool for OCaml
Name:           ocaml-%{up_name}
Version:        1.9.1
Release:        %mkrel 3
Group:          Development/OCaml
License:        BSD
Url:            http://projects.camlcity.org/projects/findlib.html
Source0:        http://download.camlcity.org/download/%{up_name}-%{version}.tar.gz

BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-compiler-libs
%if ! %with bootstrap
BuildRequires:  ocaml-camlp4-devel
BuildRequires:  ocaml-labltk-devel
%endif
BuildRequires:  pkgconfig(ncurses)
Requires:       ocaml-compiler
Obsoletes:      %{up_name} < %{version}


%description
The findlib library provides a scheme to manage reusable software
components (packages), and includes tools that support this scheme.
Packages are collections of OCaml modules for which meta-information can
be stored. The packages are kept in the file-system hierarchy, but with
strict directory structure. The library contains functions to look the
directory up that stores a package, to query meta-information about a
package, and to retrieve dependency information about multiple packages.
There is also a tool that allows the user to enter queries on the
command-line. In order to simplify compilation and linkage, there are
new front-ends of the various OCaml compilers that can directly deal with
packages.

%package devel
Summary:    Development files for %{name}
Group:      Development/OCaml
Requires:   %{name} = %{version}-%{release}


%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q -n %{up_name}-%{version}

%build
ocamlc -version
ocamlc -where
(cd tools/extract_args && make)
tools/extract_args/extract_args -o src/findlib/ocaml_args.ml ocamlc ocamlcp ocamlmktop ocamlopt ocamldep ocamldoc ||:
cat src/findlib/ocaml_args.ml
./configure -config %{_sysconfdir}/findlib.conf \
    -bindir %{_bindir} \
    -sitelib `ocamlc -where` \
    -mandir %{_mandir} \
    -with-toolbox
make all
%ifnarch %mips
make opt
%endif

%install
make prefix=%{buildroot} PREFIX=%{buildroot} install 

# don't ship META files for standard library in this package,
# they are included in ocaml package,
# [IMPORTANT] so when this package is updated, update too
# the tarball that contain these files (Source5) in the ocaml package!
rm -f %{buildroot}%{_libdir}/ocaml/bigarray/META
rm -f %{buildroot}%{_libdir}/ocaml/dbm/META
rm -f %{buildroot}%{_libdir}/ocaml/dynlink/META
rm -f %{buildroot}%{_libdir}/ocaml/graphics/META
rm -f %{buildroot}%{_libdir}/ocaml/num/META
rm -f %{buildroot}%{_libdir}/ocaml/num-top/META
rm -f %{buildroot}%{_libdir}/ocaml/stdlib/META
rm -f %{buildroot}%{_libdir}/ocaml/str/META
rm -f %{buildroot}%{_libdir}/ocaml/threads/META
rm -f %{buildroot}%{_libdir}/ocaml/unix/META
rm -f %{buildroot}%{_libdir}/ocaml/ocamlbuild/META
rm -f %{buildroot}%{_libdir}/ocaml/compiler-libs/META
rm -f %{buildroot}%{_libdir}/ocaml/bytes/META
rm -f %{buildroot}%{_libdir}/ocaml/ocamldoc/META
rm -f %{buildroot}%{_libdir}/ocaml/raw_spacetime/META

# In order to update the [Source5] field of ocaml.spec,
# in the findlib source directory run the ./configure script
# with camlp4 and ocaml-labltk properly installed, then:
# tar cfj  findlib-1.4-ocaml-4.00.1-meta-files.tar.bz2  site-lib-src/*/META
# This goes into ocaml-camlp4
rm -f %{buildroot}%{_libdir}/ocaml/camlp4/META
# This goes into ocaml-labltk
rm -f %{buildroot}%{_libdir}/ocaml/labltk/META

%files
%doc LICENSE
%config(noreplace) %{_sysconfdir}/findlib.conf
%{_bindir}/*
%{_mandir}/man*/*
%{_libdir}/ocaml/findlib
%{_libdir}/ocaml/topfind
#{_libdir}/ocaml/num-top
%exclude %{_libdir}/ocaml/findlib/*.a
%exclude %{_libdir}/ocaml/findlib/*.cmxa
%exclude %{_libdir}/ocaml/findlib/*.mli
%exclude %{_libdir}/ocaml/findlib/Makefile.config


%files devel
%doc LICENSE doc doc/README doc/guide-html
%{_libdir}/ocaml/findlib/*.a
%{_libdir}/ocaml/findlib/*.cmxa
%{_libdir}/ocaml/findlib/*.mli
%{_libdir}/ocaml/findlib/Makefile.config


%changelog
* Wed May 18 2022 pterjan <pterjan> 1.9.1-3.mga9
+ Revision: 1858730
- Rebuild for ocaml 4.14

* Tue Mar 29 2022 umeabot <umeabot> 1.9.1-2.mga9
+ Revision: 1832097
- Mageia 9 Mass Rebuild

* Tue Oct 12 2021 tv <tv> 1.9.1-1.mga9
+ Revision: 1750657
- New upstream development version 1.9.1
- OCaml 4.13.1 build

* Wed Mar 24 2021 tv <tv> 1.9-1.mga9
+ Revision: 1709038
- 1.9

* Tue Mar 02 2021 tv <tv> 1.8.1-5.mga9
+ Revision: 1696253
- rebuild for ocaml-4.2-12

* Fri Aug 21 2020 umeabot <umeabot> 1.8.1-4.mga8
+ Revision: 1617568
- Rebuild for new ocaml deps generator

* Thu Feb 27 2020 pterjan <pterjan> 1.8.1-3.mga8
+ Revision: 1551104
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1.8.1-2.mga8
+ Revision: 1543226
- Mageia 8 Mass Rebuild

* Sun Jan 19 2020 tv <tv> 1.8.1-1.mga8
+ Revision: 1481490
- new release + rebuild for ocaml-4.10

* Mon Oct 22 2018 pterjan <pterjan> 1.8.0-4.mga7
+ Revision: 1323739
- Rebuild for ocaml 4.07

* Mon Oct 22 2018 pterjan <pterjan> 1.8.0-3.mga7
+ Revision: 1323679
- Rebuild for ocaml 4.07

* Sun Sep 23 2018 umeabot <umeabot> 1.8.0-2.mga7
+ Revision: 1299870
- Mageia 7 Mass Rebuild

* Thu Apr 26 2018 daviddavid <daviddavid> 1.8.0-1.mga7
+ Revision: 1222699
- new version: 1.8.0
- remove upstream patches

* Sat Jan 06 2018 tv <tv> 1.7.3-3.mga7
+ Revision: 1190598
- add upstream patch to fix detection of "num" package

* Sun Nov 26 2017 tv <tv> 1.7.3-2.mga7
+ Revision: 1179416
- fix parsing some -Wl options (eg: for cairo)

* Sat Nov 25 2017 tv <tv> 1.7.3-1.mga7
+ Revision: 1179202
- new release
- enable bootstrap
- rebuild for new ocaml

* Fri Oct 06 2017 daviddavid <daviddavid> 1.6.1-4.mga7
+ Revision: 1169360
- fix dependency version on ocaml-compiler

* Fri Oct 06 2017 daviddavid <daviddavid> 1.6.1-3.mga7
+ Revision: 1169351
- patch0: enable debugging information thus fixing empty debugsourcefiles.list

* Mon Sep 26 2016 pterjan <pterjan> 1.6.1-2.mga6
+ Revision: 1056347
- Rebuild for fix in ocaml

* Fri Jan 29 2016 pterjan <pterjan> 1.6.1-1.mga6
+ Revision: 928670
- Update to 1.6.1

* Wed Oct 15 2014 umeabot <umeabot> 1.4.1-4.mga5
+ Revision: 750507
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 1.4.1-3.mga5
+ Revision: 725146
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1.4.1-2.mga5
+ Revision: 683034
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 malo <malo> 1.4.1-1.mga5
+ Revision: 673906
- update to 1.4.1

* Sat Oct 19 2013 umeabot <umeabot> 1.4-4.mga4
+ Revision: 534660
- Mageia 4 Mass Rebuild

* Fri Sep 13 2013 blue_prawn <blue_prawn> 1.4-3.mga4
+ Revision: 478518
- rebuild for ocaml-4.01.0

* Sat Sep 07 2013 blue_prawn <blue_prawn> 1.4-2.mga4
+ Revision: 475746
- rebuild for ocaml-4.01.0

* Wed Jul 31 2013 blue_prawn <blue_prawn> 1.4-1.mga4
+ Revision: 461621
- updated to last version 1.4

* Sat Mar 09 2013 rtp <rtp> 1.3.3-8.mga3
+ Revision: 401976
- enable build with ocaml opt on arm

* Sat Jan 12 2013 umeabot <umeabot> 1.3.3-7.mga3
+ Revision: 361349
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Oct 09 2012 fwang <fwang> 1.3.3-6.mga3
+ Revision: 303839
- rebuild fo rnew ocaml-compiler

* Sun Sep 30 2012 malo <malo> 1.3.3-5.mga3
+ Revision: 301002
- rebuild for new ocaml

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.3.3-4.mga3
+ Revision: 300022
- added -bindir configure option
- compiler-libs/META
- new rpm group for ocaml

* Sat Jul 21 2012 malo <malo> 1.3.3-3.mga3
+ Revision: 273128
- fix requires to ocaml-compiler

* Sat Jul 21 2012 malo <malo> 1.3.3-2.mga3
+ Revision: 273121
- fix requires for ocaml-compiler

* Sat Jul 21 2012 malo <malo> 1.3.3-1.mga3
+ Revision: 273106
- update to 1.3.3

* Sat Mar 03 2012 blue_prawn <blue_prawn> 1.2.8-1.mga2
+ Revision: 217454
- updated to new version 1.2.8

* Sun Oct 02 2011 shlomif <shlomif> 1.2.7-1.mga2
+ Revision: 150980
- New version - 1.2.7 - thanks to Malo

* Sun Oct 02 2011 fwang <fwang> 1.2.6-3.mga2
+ Revision: 150885
- add requires on ocaml

* Sun Oct 02 2011 fwang <fwang> 1.2.6-2.mga2
+ Revision: 150871
- rebuild for new ocaml

* Mon Mar 07 2011 saispo <saispo> 1.2.6-1.mga1
+ Revision: 66114
- imported package ocaml-findlib

